<?php
/**
 * Copyright © 2015 Infomodus. All rights reserved.
 */

namespace Infomodus\Upslabel\Controller\Adminhtml\Items;

class Bulk extends \Infomodus\Upslabel\Controller\Adminhtml\Items\AbstractMassAction
{
    protected $_conf;
    protected $collectionFactory;
    protected $shipmentCollectionFactory;
    protected $creditmemoCollectionFactory;
    protected $labelCollectionFactory;
    protected $fileFactory;

    public function __construct(
        \Magento\Ui\Component\MassAction\Filter $filter,
        \Magento\Framework\Registry $registry,
        \Magento\Backend\App\Action\Context $context,
        \Magento\Sales\Model\ResourceModel\Order\CollectionFactory $collectionFactory,
        \Magento\Sales\Model\ResourceModel\Order\Shipment\CollectionFactory $shipmentCollectionFactory,
        \Magento\Sales\Model\ResourceModel\Order\Creditmemo\CollectionFactory $creditmemoCollectionFactory,
        \Infomodus\Upslabel\Model\Resource\Items\CollectionFactory $labelCollectionFactory,
        \Magento\Framework\App\Response\Http\FileFactory $fileFactory,
        \Infomodus\Upslabel\Helper\Config $conf
    )
    {
        $this->_conf = $conf;
        $this->collectionFactory = $collectionFactory;
        $this->shipmentCollectionFactory = $shipmentCollectionFactory;
        $this->creditmemoCollectionFactory = $creditmemoCollectionFactory;
        $this->labelCollectionFactory = $labelCollectionFactory;
        $this->fileFactory = $fileFactory;
        parent::__construct($context, $filter);
    }

    protected function massAction(\Magento\Framework\Model\ResourceModel\Db\Collection\AbstractCollection $collection)
    {
        $ids = $collection->getAllIds();
        if (count($ids) > 0) {
            $isOrder = false;
            switch ($this->getRequest()->getParam('namespace')) {
                case 'sales_order_grid':
                    $type = 'shipment';
                    $isOrder = true;
                    $errorLink = 'sales/order';
                    break;
                case 'sales_order_shipment_grid':
                    $isOrder = true;
                    $type = 'shipment';
                    $errorLink = 'sales/shipment';
                    break;
                case 'sales_order_creditmemo_grid':
                    $type = 'refund';
                    $errorLink = 'sales/creditmemo';
                    break;
                default:
                    $type = 'shipment';
                    $errorLink = 'infomodus_upslabel/items';
                    break;
            }
            $isOk = false;
            foreach ($ids as $id) {
                $handy = $this->_conf->objectManager->get('Infomodus\Upslabel\Helper\Handy');
                if ($isOrder === true) {
                    $order = $this->_conf->objectManager->get('Magento\Sales\Model\Order')->load($id);
                    $storeId = $order->getStoreId();
                    /*multistore*/
                    $shippingActiveMethods = trim($this->_conf->getStoreConfig('upslabel/frontend_autocreate_label/apply_to', $storeId), " ,");
                    $shippingActiveMethods = strlen($shippingActiveMethods) > 0 ? explode(",", $shippingActiveMethods) : array();
                    $orderStatuses = explode(",", trim($this->_conf->getStoreConfig('upslabel/frontend_autocreate_label/orderstatus', $storeId), " ,"));
                    if (
                        isset($shippingActiveMethods)
                        && count($shippingActiveMethods) > 0
                        && in_array($order->getShippingMethod(), $shippingActiveMethods)
                        && isset($orderStatuses) && count($orderStatuses) > 0 && in_array($order->getStatus(), $orderStatuses)
                    ) {
                        $handy->intermediate($id, $type);
                        $handy->defConfParams['package'] = $handy->defPackageParams;
                        $handy->getLabel(NULL, $type, NULL, $handy->defConfParams);
                    }
                } else {
                    $handy->intermediate(NULL, $type, $id);
                    $handy->defConfParams['package'] = $handy->defPackageParams;
                    $handy->getLabel(NULL, $type, $id, $handy->defConfParams);
                }

                if (count($handy->error) == 0) {
                    $isOk = true;
                } else {
                    $this->messageManager->addError(__('For the selected items are not created labels.'));
                }

            }
            if ($isOk === true) {
                $this->messageManager->addSuccess(__('For the selected items are created labels.'));
            }
            return $this->resultRedirectFactory->create()->setPath($errorLink . '/');
        }
    }
}
